==> cscec5b-wzxt-api-3.0.1-20230905.111910-330-sources.jar: com/ejianc/business/wzxt/vo/CheckSynergyVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonFormat.Shape;
import java.util.Date;

/**
 * 协同确认VO
 *
 * @author generator
 *
 */

public class CheckSynergyVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long synergyNumber; // 协同号
    private Long checkId; // 验收主键
    private Long affirmId; // 确认人id
    private String affirmPerson; // 确认人
    private Integer affirmState; // 确认状态 0 未确认 1 已确认
    private Long projectId; // 项目
    private String projectName; // 项目名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date checkDate; // 验收日期
    private Long employeeId; // 验收人
    private String employeeName; // 验收人名称
    private String licensePlate; // 车牌号
    private java.lang.String billCode; // 验收单号
    private java.lang.Long supplierId; // 供应商id
    private java.lang.String supplierName; // 供应商名称
    @JsonFormat(
            shape = Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private Date affirmTime; // 确认时间

    public Date getAffirmTime() {
        return affirmTime;
    }

    public void setAffirmTime(Date affirmTime) {
        this.affirmTime = affirmTime;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getAffirmId() {
        return affirmId;
    }

    public void setAffirmId(Long affirmId) {
        this.affirmId = affirmId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(Date checkDate) {
        this.checkDate = checkDate;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getLicensePlate() {
        return licensePlate;
    }

    public void setLicensePlate(String licensePlate) {
        this.licensePlate = licensePlate;
    }

    public Long getSynergyNumber() {
        return synergyNumber;
    }

    public void setSynergyNumber(Long synergyNumber) {
        this.synergyNumber = synergyNumber;
    }

    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }

    public String getAffirmPerson() {
        return affirmPerson;
    }

    public void setAffirmPerson(String affirmPerson) {
        this.affirmPerson = affirmPerson;
    }

    public Integer getAffirmState() {
        return affirmState;
    }

    public void setAffirmState(Integer affirmState) {
        this.affirmState = affirmState;
    }
}

==> cscec5b-wzxt-api-3.0.1-20231114.075446-349-sources.jar: com/ejianc/business/wzxt/vo/CheckSynergyVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonFormat.Shape;
import java.util.Date;

/**
 * 协同确认VO
 *
 * @author generator
 *
 */

public class CheckSynergyVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String synergyNumber; // 协同号
    private Long checkId; // 验收主键
    private Long affirmId; // 确认人id
    private String affirmPerson; // 确认人
    private Integer affirmState; // 确认状态 0 未确认 1 已确认
    private Long projectId; // 项目
    private String projectName; // 项目名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date checkDate; // 验收日期
    private Long employeeId; // 验收人
    private String employeeName; // 验收人名称
    private String licensePlate; // 车牌号
    private java.lang.String billCode; // 验收单号
    private java.lang.Long supplierId; // 供应商id
    private java.lang.String supplierName; // 供应商名称
    @JsonFormat(
            shape = Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private Date affirmTime; // 确认时间

    public Date getAffirmTime() {
        return affirmTime;
    }

    public void setAffirmTime(Date affirmTime) {
        this.affirmTime = affirmTime;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getAffirmId() {
        return affirmId;
    }

    public void setAffirmId(Long affirmId) {
        this.affirmId = affirmId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(Date checkDate) {
        this.checkDate = checkDate;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getLicensePlate() {
        return licensePlate;
    }

    public void setLicensePlate(String licensePlate) {
        this.licensePlate = licensePlate;
    }

    public String getSynergyNumber() {
        return synergyNumber;
    }

    public void setSynergyNumber(String synergyNumber) {
        this.synergyNumber = synergyNumber;
    }

    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }

    public String getAffirmPerson() {
        return affirmPerson;
    }

    public void setAffirmPerson(String affirmPerson) {
        this.affirmPerson = affirmPerson;
    }

    public Integer getAffirmState() {
        return affirmState;
    }

    public void setAffirmState(Integer affirmState) {
        this.affirmState = affirmState;
    }
}
